function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { isObject } from 'lodash'; // @ts-ignore

import { saveAs } from '@elastic/filesaver';
var LINE_FEED_CHARACTER = '\r\n';
var nonAlphaNumRE = /[^a-zA-Z0-9]/;
var allDoubleQuoteRE = /"/g;

function escape(val, quoteValues) {
  if (isObject(val)) {
    val = val.valueOf();
  }

  val = String(val);

  if (quoteValues && nonAlphaNumRE.test(val)) {
    val = "\"".concat(val.replace(allDoubleQuoteRE, '""'), "\"");
  }

  return val;
}

function buildCsv(columns, rows, csvSeparator, quoteValues, valueFormatter) {
  // Build the header row by its names
  var header = columns.map(function (col) {
    return escape(col.name, quoteValues);
  }); // Convert the array of row objects to an array of row arrays

  var orderedFieldNames = columns.map(function (col) {
    return col.field;
  });
  var csvRows = rows.map(function (row) {
    return orderedFieldNames.map(function (field) {
      return escape(valueFormatter ? valueFormatter(row[field]) : row[field], quoteValues);
    });
  });
  return [header].concat(_toConsumableArray(csvRows)).map(function (row) {
    return row.join(csvSeparator);
  }).join(LINE_FEED_CHARACTER) + LINE_FEED_CHARACTER; // Add \r\n after last line
}

export function exportAsCsv(_ref) {
  var filename = _ref.filename,
      columns = _ref.columns,
      rows = _ref.rows,
      valueFormatter = _ref.valueFormatter,
      csvSeparator = _ref.csvSeparator,
      quoteValues = _ref.quoteValues;
  var type = 'text/plain;charset=utf-8';
  var csv = new Blob([buildCsv(columns, rows, csvSeparator, quoteValues, valueFormatter)], {
    type: type
  });
  saveAs(csv, filename);
}