/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React, { useEffect } from 'react';
import { EuiSpacer } from '@elastic/eui';
import { AggGroupNames } from '../../../../data/public';
import { useSubAggParamsHandlers } from './utils';
import { DefaultEditorAggParams } from '../agg_params';

function SubAggParamEditor(_ref) {
  var agg = _ref.agg,
      aggParam = _ref.aggParam,
      formIsTouched = _ref.formIsTouched,
      metricAggs = _ref.metricAggs,
      state = _ref.state,
      setValue = _ref.setValue,
      setValidity = _ref.setValidity,
      setTouched = _ref.setTouched,
      schemas = _ref.schemas;
  useEffect(function () {
    // we aren't creating a custom aggConfig
    if (agg.params.metricAgg !== 'custom') {
      setValue(undefined);
    } else if (!agg.params.customMetric) {
      setValue(aggParam.makeAgg(agg));
    }
  }, [metricAggs, agg, setValue, aggParam]);

  var _useSubAggParamsHandl = useSubAggParamsHandlers(agg, aggParam, agg.params.customMetric, setValue),
      onAggTypeChange = _useSubAggParamsHandl.onAggTypeChange,
      setAggParamValue = _useSubAggParamsHandl.setAggParamValue;

  if (agg.params.metricAgg !== 'custom' || !agg.params.customMetric) {
    return null;
  }

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(EuiSpacer, {
    size: "m"
  }), /*#__PURE__*/React.createElement(DefaultEditorAggParams, {
    agg: agg.params.customMetric,
    allowedAggs: aggParam.allowedAggs,
    groupName: AggGroupNames.Metrics,
    className: "visEditorAgg__subAgg",
    formIsTouched: formIsTouched,
    indexPattern: agg.getIndexPattern(),
    metricAggs: metricAggs,
    state: state,
    setAggParamValue: setAggParamValue,
    onAggTypeChange: onAggTypeChange,
    setValidity: setValidity,
    setTouched: setTouched,
    schemas: schemas,
    hideCustomLabel: true
  }));
}

export { SubAggParamEditor };