function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import './index.scss';
import React, { useEffect, useRef, useState, useCallback } from 'react';
import { KibanaContextProvider, PanelsContainer, Panel } from '../../kibana_react/public';
import { Storage } from '../../kibana_utils/public';
import { DefaultEditorSideBar } from './components/sidebar';
import { getInitialWidth } from './editor_size';
var localStorage = new Storage(window.localStorage);

function DefaultEditor(_ref) {
  var core = _ref.core,
      data = _ref.data,
      vis = _ref.vis,
      uiState = _ref.uiState,
      timeRange = _ref.timeRange,
      filters = _ref.filters,
      optionTabs = _ref.optionTabs,
      query = _ref.query,
      embeddableHandler = _ref.embeddableHandler,
      eventEmitter = _ref.eventEmitter,
      linked = _ref.linked,
      savedSearch = _ref.savedSearch;
  var visRef = useRef(null);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      isCollapsed = _useState2[0],
      setIsCollapsed = _useState2[1];

  var onClickCollapse = useCallback(function () {
    setIsCollapsed(function (value) {
      return !value;
    });
  }, []);
  useEffect(function () {
    if (!visRef.current) {
      return;
    }

    embeddableHandler.render(visRef.current);
    setTimeout(function () {
      eventEmitter.emit('embeddableRendered');
    });
    return function () {
      return embeddableHandler.destroy();
    };
  }, [embeddableHandler, eventEmitter]);
  useEffect(function () {
    embeddableHandler.updateInput({
      timeRange: timeRange,
      filters: filters,
      query: query
    });
  }, [embeddableHandler, timeRange, filters, query]);
  var editorInitialWidth = getInitialWidth(vis.type.editorConfig.defaultSize);
  return /*#__PURE__*/React.createElement(core.i18n.Context, null, /*#__PURE__*/React.createElement(KibanaContextProvider, {
    services: _objectSpread({
      appName: 'vis_default_editor',
      storage: localStorage,
      data: data
    }, core)
  }, /*#__PURE__*/React.createElement(PanelsContainer, {
    className: "visEditor--default",
    resizerClassName: "visEditor__resizer ".concat(isCollapsed ? 'visEditor__resizer-isHidden' : '')
  }, /*#__PURE__*/React.createElement(Panel, {
    className: "visEditor__visualization",
    initialWidth: 100 - editorInitialWidth
  }, /*#__PURE__*/React.createElement("div", {
    className: "visEditor__canvas",
    ref: visRef,
    "data-shared-items-container": true
  })), /*#__PURE__*/React.createElement(Panel, {
    className: "visEditor__collapsibleSidebar ".concat(isCollapsed ? 'visEditor__collapsibleSidebar-isClosed' : ''),
    initialWidth: editorInitialWidth
  }, /*#__PURE__*/React.createElement(DefaultEditorSideBar, {
    embeddableHandler: embeddableHandler,
    isCollapsed: isCollapsed,
    onClickCollapse: onClickCollapse,
    optionTabs: optionTabs,
    vis: vis,
    uiState: uiState,
    isLinkedSearch: linked,
    savedSearch: savedSearch,
    timeRange: timeRange,
    eventEmitter: eventEmitter
  })))));
} // default export required for React.Lazy
// eslint-disable-next-line import/no-default-export


export { DefaultEditor as default };