function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { partial } from 'lodash';
import { getPoint } from './_get_point';
import { addToSiri } from './_add_to_siri';
export function getSeries(table, chart) {
  var aspects = chart.aspects;
  var xAspect = aspects.x[0];
  var yAspect = aspects.y[0];
  var zAspect = aspects.z && aspects.z[0];
  var multiY = Array.isArray(aspects.y) && aspects.y.length > 1;
  var partGetPoint = partial(getPoint, table, xAspect, aspects.series);
  var seriesMap = new Map();
  table.rows.forEach(function (row, rowIndex) {
    if (!multiY) {
      var point = partGetPoint(row, rowIndex, yAspect, zAspect);

      if (point) {
        var id = "".concat(point.series, "-").concat(yAspect.accessor);
        point.seriesId = id;
        addToSiri(seriesMap, point, id, point.series, yAspect.format, zAspect && zAspect.format, zAspect && zAspect.title);
      }

      return;
    }

    aspects.y.forEach(function (y) {
      var point = partGetPoint(row, rowIndex, y, zAspect);

      if (!point) {
        return;
      } // use the point's y-axis as it's series by default,
      // but augment that with series aspect if it's actually
      // available


      var seriesId = y.accessor;
      var seriesLabel = y.title;

      if (aspects.series) {
        var prefix = point.series ? point.series + ': ' : '';
        seriesId = prefix + seriesId;
        seriesLabel = prefix + seriesLabel;
      }

      point.seriesId = seriesId;
      addToSiri(seriesMap, point, seriesId, seriesLabel, y.format, zAspect && zAspect.format, zAspect && zAspect.title);
    });
  });
  return _toConsumableArray(seriesMap.values());
}