function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { visTypeAliasRegistry, VisTypeAlias } from './vis_type_alias_registry'; // @ts-ignore

import { BaseVisType } from './base_vis_type'; // @ts-ignore

import { ReactVisType } from './react_vis_type';

/**
 * Vis Types Service
 *
 * @internal
 */
export var TypesService = /*#__PURE__*/function () {
  function TypesService() {
    _classCallCheck(this, TypesService);

    _defineProperty(this, "types", {});

    _defineProperty(this, "unregisteredHiddenTypes", []);
  }

  _createClass(TypesService, [{
    key: "setup",
    value: function setup() {
      var _this = this;

      var registerVisualization = function registerVisualization(registerFn) {
        var visDefinition = registerFn();

        if (_this.unregisteredHiddenTypes.includes(visDefinition.name)) {
          visDefinition.hidden = true;
        }

        if (_this.types[visDefinition.name]) {
          throw new Error('type already exists!');
        }

        _this.types[visDefinition.name] = visDefinition;
      };

      return {
        /**
         * registers a visualization type
         * @param {VisType} config - visualization type definition
         */
        createBaseVisualization: function createBaseVisualization(config) {
          var vis = new BaseVisType(config);
          registerVisualization(function () {
            return vis;
          });
        },

        /**
         * registers a visualization which uses react for rendering
         * @param {VisType} config - visualization type definition
         */
        createReactVisualization: function createReactVisualization(config) {
          var vis = new ReactVisType(config);
          registerVisualization(function () {
            return vis;
          });
        },

        /**
         * registers a visualization alias
         * alias is a visualization type without implementation, it just redirects somewhere in kibana
         * @param {VisTypeAlias} config - visualization alias definition
         */
        registerAlias: visTypeAliasRegistry.add,

        /**
         * allows to hide specific visualization types from create visualization dialog
         * @param {string[]} typeNames - list of type ids to hide
         */
        hideTypes: function hideTypes(typeNames) {
          typeNames.forEach(function (name) {
            if (_this.types[name]) {
              _this.types[name].hidden = true;
            } else {
              _this.unregisteredHiddenTypes.push(name);
            }
          });
        }
      };
    }
  }, {
    key: "start",
    value: function start() {
      var _this2 = this;

      return {
        /**
         * returns specific visualization or undefined if not found
         * @param {string} visualization - id of visualization to return
         */
        get: function get(visualization) {
          return _this2.types[visualization];
        },

        /**
         * returns all registered visualization types
         */
        all: function all() {
          return _toConsumableArray(Object.values(_this2.types));
        },

        /**
         * returns all registered aliases
         */
        getAliases: visTypeAliasRegistry.get
      };
    }
  }, {
    key: "stop",
    value: function stop() {// nothing to do here yet
    }
  }]);

  return TypesService;
}();
/** @internal */

/** @public types */
export { VisTypeAlias };
/** @public static code */
// TODO once items are moved from ui/vis into this service